@@ -1,9 +1,23 @@
 import re
+import numba
 
 import torch
 import numpy as np
 import scipy.sparse as sparse
 
+import time
+
+
+@numba.njit
+def reindex(node_idx, col):
+    node_dict = dict()
+    cnt = 0
+    for i in node_idx:
+        node_dict[i] = cnt
+        cnt += 1
+    new_col = [node_dict[i] for i in col]
+    return np.array(new_col)
+
 
 class Data(object):
     r"""A plain old python object modeling a single graph with various
@@ -113,6 +127,9 @@ class Data(object):
         # creating batches.
         return self.num_nodes if bool(re.search("(index|face)", key)) else 0
 
+    def __cat_dim__(self, key, value):
+        return self.cat_dim(key, value)
+
     @property
     def num_edges(self):
         r"""Returns the number of edges in the graph."""
@@ -123,6 +140,8 @@ class Data(object):
     @property
     def num_features(self):
         r"""Returns the number of features per node in the graph."""
+        if self.x is None:
+            return 0
         return 1 if self.x.dim() == 1 else self.x.size(1)
 
     @property
@@ -153,6 +172,8 @@ class Data(object):
         attributes.
         """
         for key, item in self(*keys):
+            if not isinstance(item, torch.Tensor):
+                continue
             self[key] = func(item)
         return self
 
@@ -178,13 +199,32 @@ class Data(object):
     def _build_adj_(self):
         if self.__adj is not None:
             return
+
         num_edges = self.edge_index.shape[1]
+
+        if str(self.edge_index.device) == "cpu":
+            edge_index = self.edge_index
+        else:
+            edge_index = self.edge_index.cpu()
+        self.edge_row = edge_index[0]
+
+        self.edge_col = edge_index[1].numpy()
+
+        self.node_idx = torch.unique(self.edge_index).cpu().numpy()
+
         edge_index_np = self.edge_index.cpu().numpy()
         num_nodes = self.x.shape[0]
         edge_attr_np = np.ones(num_edges)
         self.__adj = sparse.csr_matrix(
             (edge_attr_np, (edge_index_np[0], edge_index_np[1])), shape=(num_nodes, num_nodes)
         )
+        return self.__adj
+
+    def _eliminate_adj_(self):
+        self.__adj = None
+        self.edge_row = None
+        self.edge_col = None
+        self.node_idx = None
 
     def subgraph(self, node_idx):
         """Return the induced node subgraph."""
@@ -200,13 +240,14 @@ class Data(object):
         edge_attr = torch.from_numpy(adj_coo.data).to(self.x.device)
         edge_index = torch.from_numpy(np.stack([row, col], axis=0)).to(self.x.device).long()
         keys = self.keys
-        attrs = {key: self[key][node_idx] for key in keys if "edge" not in key}
+
+        attrs = {key: self[key][node_idx] for key in keys if "edge" not in key and "node_idx" not in key}
         attrs["edge_index"] = edge_index
         if edge_attr is not None:
             attrs["edge_attr"] = edge_attr
         return Data(**attrs)
 
-    def edge_subgraph(self, edge_idx):
+    def edge_subgraph(self, edge_idx, require_idx=False):
         """Return the induced edge subgraph."""
         if isinstance(edge_idx, torch.Tensor):
             edge_idx = edge_idx.cpu().numpy()
@@ -226,6 +267,8 @@ class Data(object):
         attrs["edge_index"] = edge_index
         if edge_attr is not None:
             attrs["edge_attr"] = edge_attr
+        if require_idx:
+            return Data(**attrs), node_idx, edge_idx
         return Data(**attrs)
 
     def sample_adj(self, batch, size=-1, replace=True):
@@ -235,40 +278,35 @@ class Data(object):
         if isinstance(batch, torch.Tensor):
             batch = batch.cpu().numpy()
 
-        adj = self.__adj[batch].tocsr()
+        adj = self.__adj[batch]
         batch_size = len(batch)
         if size == -1:
-            adj = adj.tocoo()
-            row, col = torch.from_numpy(adj.row), torch.from_numpy(adj.col)
-            node_idx = torch.unique(col)
+            row, col = self.edge_row, self.edge_col
+            _node_idx = self.node_idx
         else:
             indices = torch.from_numpy(adj.indices)
             indptr = torch.from_numpy(adj.indptr)
             node_idx, (row, col) = self._sample_adj(batch_size, indices, indptr, size)
-        col = col.numpy()
-        _node_idx = node_idx.numpy()
+            col = col.numpy()
+            _node_idx = node_idx.numpy()
 
         # Reindexing: target nodes are always put at the front
-        _node_idx = list(batch) + list(set(_node_idx).difference(set(batch)))
-        node_dict = {val: key for key, val in enumerate(_node_idx)}
-        new_col = torch.LongTensor([node_dict[i] for i in col])
+        _node_idx = np.concatenate((batch, np.setdiff1d(_node_idx, batch)))
+
+        new_col = torch.as_tensor(reindex(_node_idx, col), dtype=torch.long)
         edge_index = torch.stack([row.long(), new_col])
 
-        node_idx = torch.Tensor(_node_idx).long().to(self.x.device)
+        node_idx = torch.as_tensor(_node_idx, dtype=torch.long).to(self.x.device)
         edge_index = edge_index.long().to(self.x.device)
         return node_idx, edge_index
 
     def _sample_adj(self, batch_size, indices, indptr, size):
-        indptr = indptr
-        row_counts = torch.Tensor([indptr[i] - indptr[i - 1] for i in range(1, len(indptr))])
+        row_counts = torch.as_tensor([indptr[i] - indptr[i - 1] for i in range(1, len(indptr))]).long()
 
-        # if not replace:
-        #     edge_cols = [col[indptr[i]: indptr[i+1]] for i in range(len(indptr)-1)]
-        #     edge_cols = [np.random.choice(x, min(size, len(x)), replace=False) for x in edge_cols]
-        # else:
         rand = torch.rand(batch_size, size)
         rand = rand * row_counts.view(-1, 1)
         rand = rand.long()
+
         rand = rand + indptr[:-1].view(-1, 1)
         edge_cols = indices[rand].view(-1)
         row = torch.arange(0, batch_size).view(-1, 1).repeat(1, size).view(-1)
