@@ -83,26 +83,29 @@ class GatneDataset(Dataset):
     def __repr__(self):
         return "{}()".format(self.name)
 
+    def __len__(self):
+        return self.data.y.shape[0]
+
 
 @register_dataset("amazon")
 class AmazonDataset(GatneDataset):
-    def __init__(self, args=None):
+    def __init__(self):
         dataset = "amazon"
-        path = osp.join(osp.dirname(osp.realpath(__file__)), "../..", "data", dataset)
+        path = osp.join("data", dataset)
         super(AmazonDataset, self).__init__(path, dataset)
 
 
 @register_dataset("twitter")
 class TwitterDataset(GatneDataset):
-    def __init__(self, args=None):
+    def __init__(self):
         dataset = "twitter"
-        path = osp.join(osp.dirname(osp.realpath(__file__)), "../..", "data", dataset)
+        path = osp.join("data", dataset)
         super(TwitterDataset, self).__init__(path, dataset)
 
 
 @register_dataset("youtube")
 class YouTubeDataset(GatneDataset):
-    def __init__(self, args=None):
+    def __init__(self):
         dataset = "youtube"
-        path = osp.join(osp.dirname(osp.realpath(__file__)), "../..", "data", dataset)
+        path = osp.join("data", dataset)
         super(YouTubeDataset, self).__init__(path, dataset)
