@@ -25,7 +25,6 @@ class GTNDataset(Dataset):
         self.url = f"https://github.com/cenyk1230/gtn-data/blob/master/{name}.zip?raw=true"
         super(GTNDataset, self).__init__(root)
         self.data = torch.load(self.processed_paths[0])
-        self.num_classes = torch.max(self.data.train_target).item() + 1
         self.num_edge = len(self.data.adj)
         self.num_nodes = self.data.x.shape[0]
 
@@ -38,6 +37,10 @@ class GTNDataset(Dataset):
     def processed_file_names(self):
         return ["data.pt"]
 
+    @property
+    def num_classes(self):
+        return torch.max(self.data.train_target).item() + 1
+
     def read_gtn_data(self, folder):
         edges = pickle.load(open(osp.join(folder, "edges.pkl"), "rb"))
         labels = pickle.load(open(osp.join(folder, "labels.pkl"), "rb"))
@@ -128,23 +131,23 @@ class GTNDataset(Dataset):
 
 @register_dataset("gtn-acm")
 class ACM_GTNDataset(GTNDataset):
-    def __init__(self, args=None):
+    def __init__(self):
         dataset = "gtn-acm"
-        path = osp.join(osp.dirname(osp.realpath(__file__)), "../..", "data", dataset)
+        path = osp.join("data", dataset)
         super(ACM_GTNDataset, self).__init__(path, dataset)
 
 
 @register_dataset("gtn-dblp")
 class DBLP_GTNDataset(GTNDataset):
-    def __init__(self, args=None):
+    def __init__(self):
         dataset = "gtn-dblp"
-        path = osp.join(osp.dirname(osp.realpath(__file__)), "../..", "data", dataset)
+        path = osp.join("data", dataset)
         super(DBLP_GTNDataset, self).__init__(path, dataset)
 
 
 @register_dataset("gtn-imdb")
 class IMDB_GTNDataset(GTNDataset):
-    def __init__(self, args=None):
+    def __init__(self):
         dataset = "gtn-imdb"
-        path = osp.join(osp.dirname(osp.realpath(__file__)), "../..", "data", dataset)
+        path = osp.join("data", dataset)
         super(IMDB_GTNDataset, self).__init__(path, dataset)
