@@ -6,18 +6,20 @@ import torch.nn.functional as F
 from .. import BaseModel, register_model
 from .knowledge_base import KGEModel
 
+
 @register_model("complex")
 class ComplEx(KGEModel):
     r"""
     the implementation of ComplEx model from the paper `"Complex Embeddings for Simple Link Prediction"<http://proceedings.mlr.press/v48/trouillon16.pdf>`
-    borrowed from `KnowledgeGraphEmbedding<https://github.com/DeepGraphLearning/KnowledgeGraphEmbedding>` 
+    borrowed from `KnowledgeGraphEmbedding<https://github.com/DeepGraphLearning/KnowledgeGraphEmbedding>`
     """
+
     def score(self, head, relation, tail, mode):
         re_head, im_head = torch.chunk(head, 2, dim=2)
         re_relation, im_relation = torch.chunk(relation, 2, dim=2)
         re_tail, im_tail = torch.chunk(tail, 2, dim=2)
 
-        if mode == 'head-batch':
+        if mode == "head-batch":
             re_score = re_relation * re_tail + im_relation * im_tail
             im_score = re_relation * im_tail - im_relation * re_tail
             score = re_head * re_score + im_head * im_score
@@ -26,5 +28,5 @@ class ComplEx(KGEModel):
             im_score = re_head * im_relation + im_head * re_relation
             score = re_score * re_tail + im_score * im_tail
 
-        score = score.sum(dim = 2)
+        score = score.sum(dim=2)
         return score
