@@ -6,7 +6,7 @@ import torch.nn.functional as F
 from torch.nn.parameter import Parameter
 
 from .. import BaseModel, register_model
-from cogdl.utils import add_remaining_self_loops, spmm, symmetric_normalization
+from cogdl.utils import add_remaining_self_loops, symmetric_normalization, spmm
 
 
 class GraphConvolution(nn.Module):
@@ -31,20 +31,15 @@ class GraphConvolution(nn.Module):
         if self.bias is not None:
             self.bias.data.zero_()
 
-    def forward(self, input, edge_index, edge_attr=None):
+    def forward(self, x, edge_index, edge_attr=None):
+        support = torch.mm(x, self.weight)
         if edge_attr is None:
-            edge_attr = torch.ones(edge_index.shape[1]).float().to(input.device)
-        adj = torch.sparse_coo_tensor(
-            edge_index,
-            edge_attr,
-            (input.shape[0], input.shape[0]),
-        ).to(input.device)
-        support = torch.mm(input, self.weight)
-        output = torch.spmm(adj, support)
+            edge_attr = torch.ones(edge_index.shape[1]).to(x.device)
+        out = spmm(edge_index, edge_attr, support)
         if self.bias is not None:
-            return output + self.bias
+            return out + self.bias
         else:
-            return output
+            return out
 
     def __repr__(self):
         return self.__class__.__name__ + " (" + str(self.in_features) + " -> " + str(self.out_features) + ")"
@@ -56,8 +51,8 @@ class TKipfGCN(BaseModel):
     <https://arxiv.org/abs/1609.02907>`_ paper
 
     Args:
-        num_features (int) : Number of input features.
-        num_classes (int) : Number of classes.
+        in_features (int) : Number of input features.
+        out_features (int) : Number of classes.
         hidden_size (int) : The dimension of node representation.
         dropout (float) : Dropout rate for model training.
     """
@@ -84,18 +79,29 @@ class TKipfGCN(BaseModel):
         self.num_layers = num_layers
         self.dropout = dropout
 
-    def forward(self, x, edge_index):
-
+    def get_embeddings(self, x, edge_index):
         edge_index, edge_attr = add_remaining_self_loops(edge_index, num_nodes=x.shape[0])
         edge_attr = symmetric_normalization(x.shape[0], edge_index, edge_attr)
 
         h = x
-        for i in range(self.num_layers):
+        for i in range(self.num_layers - 1):
             h = F.dropout(h, self.dropout, training=self.training)
             h = self.layers[i](h, edge_index, edge_attr)
+        return h
+
+    def forward(self, x, edge_index, edge_weight=None):
+        edge_index, edge_weight = add_remaining_self_loops(edge_index, num_nodes=x.shape[0])
+        edge_attr = symmetric_normalization(x.shape[0], edge_index, edge_weight)
+        h = x
+        for i in range(self.num_layers):
+            h = self.layers[i](h, edge_index, edge_attr)
             if i != self.num_layers - 1:
                 h = F.relu(h)
+                h = F.dropout(h, self.dropout, training=self.training)
         return h
 
     def predict(self, data):
-        return self.forward(data.x, data.edge_index)
+        if hasattr(data, "norm_aggr"):
+            return self.forward(data.x, data.edge_index, data.norm_aggr)
+        else:
+            return self.forward(data.x, data.edge_index)
