@@ -2,11 +2,10 @@ import random
 
 import torch
 import torch.nn as nn
-import torch.nn.functional as F
 from torch_geometric.nn import DynamicEdgeConv, global_max_pool
 
 from .. import BaseModel, register_model
-from .pyg_gin import GINMLP
+from .mlp import MLP
 from cogdl.data import DataLoader, Data
 
 
@@ -67,10 +66,12 @@ class DGCNN(BaseModel):
     def __init__(self, in_feats, hidden_dim, out_feats, k=20, dropout=0.5):
         super(DGCNN, self).__init__()
         mlp1 = nn.Sequential(
-            GINMLP(2 * in_feats, hidden_dim, hidden_dim, num_layers=3), nn.ReLU(), nn.BatchNorm1d(hidden_dim)
+            MLP(2 * in_feats, hidden_dim, hidden_dim, num_layers=3, norm="batchnorm"),
+            nn.ReLU(),
+            nn.BatchNorm1d(hidden_dim),
         )
         mlp2 = nn.Sequential(
-            GINMLP(2 * hidden_dim, 2 * hidden_dim, 2 * hidden_dim, num_layers=1),
+            MLP(2 * hidden_dim, 2 * hidden_dim, 2 * hidden_dim, num_layers=1, norm="batchnorm"),
             nn.ReLU(),
             nn.BatchNorm1d(2 * hidden_dim),
         )
@@ -94,8 +95,4 @@ class DGCNN(BaseModel):
         h = self.linear(torch.cat([h1, h2], dim=1))
         h = global_max_pool(h, batch.batch)
         out = self.final_mlp(h)
-        out = F.log_softmax(out, dim=-1)
-        if batch.y is not None:
-            loss = F.nll_loss(out, batch.y)
-            return out, loss
-        return out, None
+        return out
