@@ -4,7 +4,6 @@ import torch.nn.functional as F
 from torch_geometric.nn.conv import GCNConv
 
 from .. import BaseModel, register_model
-from cogdl.trainers.sampled_trainer import SAINTTrainer
 
 
 @register_model("pyg_gcn")
@@ -18,12 +17,6 @@ class GCN(BaseModel):
         parser.add_argument("--hidden-size", type=int, default=64)
         parser.add_argument("--num-layers", type=int, default=2)
         parser.add_argument("--dropout", type=float, default=0.5)
-        parser.add_argument('--sampler', default='none', type=str, help='graph samplers')
-        parser.add_argument('--sample-coverage', default=20, type=float, help='sample coverage ratio')
-        parser.add_argument('--size-subgraph', default=1200, type=int, help='subgraph size')
-        parser.add_argument('--num-walks', default=50, type=int, help='number of random walks')
-        parser.add_argument('--walk-length', default=20, type=int, help='random walk length')
-        parser.add_argument('--size-frontier', default=20, type=int, help='frontier size in multidimensional random walks')
         # fmt: on
 
     @classmethod
@@ -37,10 +30,7 @@ class GCN(BaseModel):
         )
 
     def get_trainer(self, task, args):
-        if args.sampler != "none":
-            return SAINTTrainer
-        else:
-            return None
+        return None
 
     def __init__(self, num_features, num_classes, hidden_size, num_layers, dropout):
         super(GCN, self).__init__()
@@ -62,11 +52,18 @@ class GCN(BaseModel):
         x = self.convs[-1](x, edge_index, weight)
         return F.log_softmax(x, dim=1)
 
-    def node_classification_loss(self, data):
-        return F.nll_loss(
-            self.forward(data.x, data.edge_index, None if "norm_aggr" not in data else data.norm_aggr)[data.train_mask],
-            data.y[data.train_mask],
-        )
+    def get_embeddings(self, x, edge_index, weight=None):
+        for conv in self.convs[:-1]:
+            x = F.relu(conv(x, edge_index, weight))
+            x = F.dropout(x, p=self.dropout, training=self.training)
+        return x
+
+    # def node_classification_loss(self, data):
+    #     edge_index = data.edge_index_train if hasattr(data, "edge_index_train") else data.edge_index
+    #     return F.nll_loss(
+    #         self.forward(data.x, edge_index, None if "norm_aggr" not in data else data.norm_aggr)[data.train_mask],
+    #         data.y[data.train_mask],
+    #     )
 
     def predict(self, data):
         return self.forward(data.x, data.edge_index, None if "norm_aggr" not in data else data.norm_aggr)
