@@ -1,9 +1,10 @@
 import sys
 import argparse
 
-from cogdl.datasets import DATASET_REGISTRY
-from cogdl.models import MODEL_REGISTRY
+from cogdl.datasets import DATASET_REGISTRY, try_import_dataset
+from cogdl.models import MODEL_REGISTRY, try_import_model
 from cogdl.tasks import TASK_REGISTRY
+from cogdl.trainers import TRAINER_REGISTRY, try_import_trainer
 
 
 def get_parser():
@@ -24,8 +25,8 @@ def get_parser():
     parser.add_argument('--device-id', default=[0], type=int, nargs='+',
                         help='which GPU to use')
     parser.add_argument('--save-dir', default='.', type=str)
-    parser.add_argument('--enhance', type=str, default=None, help='use prone or prone++ to enhance embedding')
     parser.add_argument('--checkpoint', action="store_true", help='load pre-trained model')
+    parser.add_argument('--use-best-config', action='store_true', help='use best config')
 
     # fmt: on
     return parser
@@ -45,7 +46,6 @@ def add_dataset_args(parser):
     group = parser.add_argument_group("Dataset and data loading")
     # fmt: off
     group.add_argument('--dataset', '-dt', metavar='DATASET', nargs='+', required=True,
-                       choices=DATASET_REGISTRY.keys(),
                        help='Dataset')
     # fmt: on
     return group
@@ -55,8 +55,19 @@ def add_model_args(parser):
     group = parser.add_argument_group("Model configuration")
     # fmt: off
     group.add_argument('--model', '-m', metavar='MODEL', nargs='+', required=True,
-                       choices=MODEL_REGISTRY.keys(),
                        help='Model Architecture')
+    group.add_argument('--fast-spmm', action="store_true", required=False,
+                       help='whether to use gespmm')
+    # fmt: on
+    return group
+
+
+def add_trainer_args(parser):
+    group = parser.add_argument_group("Trainer configuration")
+    # fmt: off
+    group.add_argument('--trainer', metavar='TRAINER', required=False,
+                       help='Trainer')
+    group.add_argument('--eval-step', type=int, default=1)
     # fmt: on
     return group
 
@@ -66,6 +77,7 @@ def get_training_parser():
     add_task_args(parser)
     add_dataset_args(parser)
     add_model_args(parser)
+    add_trainer_args(parser)
     return parser
 
 
@@ -94,9 +106,7 @@ def get_default_args(task: str, dataset, model, **kwargs):
     args, _ = parser.parse_known_args()
     args = parse_args_and_arch(parser, args)
     for key, value in kwargs.items():
-        if hasattr(args, key):
-            args.__setattr__(key, value)
-    print(args)
+        args.__setattr__(key, value)
     return args
 
 
@@ -107,13 +117,19 @@ def parse_args_and_arch(parser, args):
     # Add *-specific args to parser.
     TASK_REGISTRY[args.task].add_args(parser)
     for model in args.model:
-        MODEL_REGISTRY[model].add_args(parser)
+        if try_import_model(model):
+            MODEL_REGISTRY[model].add_args(parser)
     for dataset in args.dataset:
-        if hasattr(DATASET_REGISTRY[dataset], "add_args"):
-            DATASET_REGISTRY[dataset].add_args(parser)
+        if try_import_dataset(dataset):
+            if hasattr(DATASET_REGISTRY[dataset], "add_args"):
+                DATASET_REGISTRY[dataset].add_args(parser)
+    if "trainer" in args and args.trainer is not None:
+        # for trainer in args.trainer:
+        if try_import_trainer(args.trainer):
+            if hasattr(TRAINER_REGISTRY[args.trainer], "add_args"):
+                TRAINER_REGISTRY[args.trainer].add_args(parser)
     # Parse a second time.
     args = parser.parse_args()
-
     return args
 
 
@@ -122,7 +138,8 @@ def get_task_model_args(task, model=None):
     parser = get_training_parser()
     TASK_REGISTRY[task].add_args(parser)
     if model is not None:
-        MODEL_REGISTRY[model].add_args(parser)
+        if try_import_model(model):
+            MODEL_REGISTRY[model].add_args(parser)
     args = parser.parse_args()
     args.task = task
     if model is not None:
