@@ -29,9 +29,11 @@ class UnsupervisedNodeClassification(BaseTask):
         """Add task-specific arguments to the parser."""
         # fmt: off
         parser.add_argument("--hidden-size", type=int, default=128)
-        parser.add_argument("--num-shuffle", type=int, default=5)
+        parser.add_argument("--num-shuffle", type=int, default=1)
         parser.add_argument("--save-dir", type=str, default="./embedding")
         parser.add_argument("--load-emb-path", type=str, default=None)
+        parser.add_argument('--training-percents', default=[0.9], type=float, nargs='+')
+        parser.add_argument('--enhance', type=str, default=None, help='use prone or prone++ to enhance embedding')
         # fmt: on
 
     def __init__(self, args, dataset=None, model=None):
@@ -59,6 +61,7 @@ class UnsupervisedNodeClassification(BaseTask):
         self.save_dir = args.save_dir
         self.load_emb_path = args.load_emb_path
         self.enhance = args.enhance
+        self.training_percents = args.training_percents
         self.args = args
         self.is_weighted = self.data.edge_attr is not None
         self.device = "cpu" if not torch.cuda.is_available() or args.cpu else args.device_id[0]
@@ -125,14 +128,16 @@ class UnsupervisedNodeClassification(BaseTask):
             self.save_emb(features_matrix)
         else:
             features_matrix = np.load(self.load_emb_path)
-        # label nor multi-label
+        # label or multi-label
         label_matrix = sp.csr_matrix(self.label_matrix)
 
         return self._evaluate(features_matrix, label_matrix, self.num_shuffle)
 
     def _evaluate(self, features_matrix, label_matrix, num_shuffle):
-        # features_matrix, node2id = utils.load_embeddings(args.emb)
-        # label_matrix = utils.load_labels(args.label, node2id, divi_str=" ")
+        if len(label_matrix.shape) > 1:
+            labeled_nodes = np.nonzero(np.sum(label_matrix, axis=1) > 0)[0]
+            features_matrix = features_matrix[labeled_nodes]
+            label_matrix = label_matrix[labeled_nodes]
 
         # shuffle, to create train/test groups
         shuffles = []
@@ -141,14 +146,12 @@ class UnsupervisedNodeClassification(BaseTask):
 
         # score each train/test group
         all_results = defaultdict(list)
-        # training_percents = [0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9]
-        training_percents = [0.1, 0.3, 0.5, 0.7, 0.9]
 
-        for train_percent in training_percents:
+        for train_percent in self.training_percents:
             for shuf in shuffles:
                 X, y = shuf
 
-                training_size = int(train_percent * self.num_nodes)
+                training_size = int(train_percent * len(features_matrix))
 
                 X_train = X[:training_size, :]
                 y_train = y[:training_size, :]
@@ -156,7 +159,7 @@ class UnsupervisedNodeClassification(BaseTask):
                 X_test = X[training_size:, :]
                 y_test = y[training_size:, :]
 
-                clf = TopKRanker(LogisticRegression())
+                clf = TopKRanker(LogisticRegression(solver="liblinear"))
                 clf.fit(X_train, y_train)
 
                 # find out how many labels should be predicted
@@ -164,13 +167,9 @@ class UnsupervisedNodeClassification(BaseTask):
                 preds = clf.predict(X_test, top_k_list)
                 result = f1_score(y_test, preds, average="micro")
                 all_results[train_percent].append(result)
-            # print("micro", result)
 
         return dict(
-            (
-                f"Micro-F1 {train_percent}",
-                sum(all_results[train_percent]) / len(all_results[train_percent]),
-            )
+            (f"Micro-F1 {train_percent}", np.mean(all_results[train_percent]))
             for train_percent in sorted(all_results.keys())
         )
 
