@@ -1,5 +1,4 @@
 from abc import ABC, abstractmethod
-from argparse import ArgumentParser
 
 
 class BaseTrainer(ABC):
@@ -8,3 +7,7 @@ class BaseTrainer(ABC):
     def build_trainer_from_args(cls, args):
         """Build a new trainer instance."""
         raise NotImplementedError("Trainers must implement the build_trainer_from_args method")
+
+    @abstractmethod
+    def fit(self, model, dataset):
+        raise NotImplementedError
